@@ -28,13 +28,12 @@ from .constants import (
 from .exceptions import ISYConnectionError, ISYInvalidAuthError
 from .logging import _LOGGER, enable_logging
 
-MAX_RETRIES = 5
-
 MAX_HTTPS_CONNECTIONS_ISY = 2
 MAX_HTTP_CONNECTIONS_ISY = 5
 MAX_HTTPS_CONNECTIONS_IOX = 20
 MAX_HTTP_CONNECTIONS_IOX = 50
 
+MAX_RETRIES = 5
 RETRY_BACKOFF = [0.01, 0.10, 0.25, 1, 2]  # Seconds
 
 HTTP_OK = 200  # Valid request received, will run it
@@ -50,6 +49,8 @@ HTTP_HEADERS = {
     "Accept-Encoding": "gzip, deflate",
 }
 
+EMPTY_XML_RESPONSE = '<?xml version="1.0" encoding="UTF-8"?>'
+
 
 class Connection:
     """Connection object to manage connection to and interaction with ISY."""
@@ -78,6 +79,7 @@ class Connection:
         self.req_session = websession
         self._tls_ver = tls_ver
         self.use_https = use_https
+        self._url = f"http{'s' if self.use_https else ''}://{self._address}:{self._port}{self._webroot}"
 
         self.semaphore = asyncio.Semaphore(
             MAX_HTTPS_CONNECTIONS_ISY if use_https else MAX_HTTP_CONNECTIONS_ISY
@@ -121,11 +123,15 @@ class Connection:
 
         return connection_info
 
+    @property
+    def url(self):
+        """Return the full connection url."""
+        return self._url
+
     # COMMON UTILITIES
     def compile_url(self, path, query=None):
         """Compile the URL to fetch from the ISY."""
-        url = "https://" if self.use_https else "http://"
-        url += f"{self._address}:{self._port}{self._webroot}"
+        url = self.url
         if path is not None:
             url += "/rest/" + "/".join([quote(item) for item in path])
 
@@ -151,7 +157,10 @@ class Connection:
                 if res.status == HTTP_OK:
                     _LOGGER.debug("ISY Response Received: %s", endpoint)
                     results = await res.text(encoding="utf-8", errors="ignore")
-                    return results
+                    if results != EMPTY_XML_RESPONSE:
+                        return results
+                    _LOGGER.debug("Invalid empty XML returned: %s", endpoint)
+                    res.release()
                 if res.status == HTTP_NOT_FOUND:
                     if ok404:
                         _LOGGER.debug("ISY Response Received %s", endpoint)
